@@ -17,6 +17,7 @@ from .internal_utils import (
     get_user_agent,
 )
 from .webhook_response import WebhookResponse
+from ..proxy_env_variable_loader import load_http_proxy_from_env
 
 
 class WebhookClient:
@@ -58,6 +59,11 @@ class WebhookClient:
         )
         self.logger = logger if logger is not None else logging.getLogger(__name__)
 
+        if self.proxy is None or len(self.proxy.strip()) == 0:
+            env_variable = load_http_proxy_from_env(self.logger)
+            if env_variable is not None:
+                self.proxy = env_variable
+
     def send(
         self,
         *,
